package com.example.library;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/books")
public class BookController {

  private final LibraryService service;

  public BookController(LibraryService service) {
    this.service = service;
  }

  @PostMapping
  public ResponseEntity<Book> addBook(@RequestBody Book book) {
    return ResponseEntity.ok(service.addBook(book));
  }

  @GetMapping
  public ResponseEntity<List<Book>> getAllBooks() {
    return ResponseEntity.ok(service.findAllBooks());
  }

  @PostMapping("/{id}/borrow")
  public ResponseEntity<String> borrowBook(@PathVariable Long id) {
    boolean success = service.borrowBook(id);
    return success
        ? ResponseEntity.ok("Book borrowed.")
        : ResponseEntity.badRequest().body("Book not available or not found.");
  }

  @PostMapping("/{id}/return")
  public ResponseEntity<String> returnBook(@PathVariable Long id) {
    boolean success = service.returnBook(id);
    return success
        ? ResponseEntity.ok("Book returned.")
        : ResponseEntity.badRequest().body("Book is already available or not found.");
  }
}