package com.example.library;

import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Optional;

@Service
public class LibraryService {

  private final BookRepository repository;

  public LibraryService(BookRepository repository) {
    this.repository = repository;
  }

  public Book addBook(Book book) {
    book.setAvailable(true); // nová kniha je dostupná
    return repository.save(book);
  }

  public List<Book> findAllBooks() {
    return repository.findAll();
  }

  public Optional<Book> findBookById(Long id) {
    return repository.findById(id);
  }

  public boolean borrowBook(Long bookId) {
    return repository.findById(bookId)
        .filter(Book::isAvailable)
        .map(book -> {
          book.setAvailable(false);
          repository.save(book);
          return true;
        })
        .orElse(false);
  }

  public boolean returnBook(Long bookId) {
    return repository.findById(bookId)
        .filter(book -> !book.isAvailable())
        .map(book -> {
          book.setAvailable(true);
          repository.save(book);
          return true;
        })
        .orElse(false);
  }
}